@@ -73,6 +73,14 @@ class Envelope:
         # type: (...) -> None
         self.add_item(Item(payload=PayloadRef(json=profile), type="profile"))
 
+    def add_profile_chunk(
+        self, profile_chunk  # type: Any
+    ):
+        # type: (...) -> None
+        self.add_item(
+            Item(payload=PayloadRef(json=profile_chunk), type="profile_chunk")
+        )
+
     def add_checkin(
         self, checkin  # type: Any
     ):
@@ -265,6 +273,8 @@ class Item:
             return "internal"
         elif ty == "profile":
             return "profile"
+        elif ty == "profile_chunk":
+            return "profile_chunk"
         elif ty == "statsd":
             return "metric_bucket"
         elif ty == "check_in":
