@@ -1,14 +1,14 @@
-from __future__ import absolute_import
-
-from sentry_sdk._compat import text_type
+import sentry_sdk
 from sentry_sdk._types import TYPE_CHECKING
 from sentry_sdk.consts import SPANDATA
 from sentry_sdk.db.explain_plan.sqlalchemy import attach_explain_plan_to_span
-from sentry_sdk.hub import Hub
 from sentry_sdk.integrations import Integration, DidNotEnable
-from sentry_sdk.tracing_utils import record_sql_queries
-
-from sentry_sdk.utils import parse_version
+from sentry_sdk.tracing_utils import add_query_source, record_sql_queries
+from sentry_sdk.utils import (
+    capture_internal_exceptions,
+    ensure_integration_enabled,
+    parse_version,
+)
 
 try:
     from sqlalchemy.engine import Engine  # type: ignore
@@ -47,16 +47,12 @@ class SqlalchemyIntegration(Integration):
         listen(Engine, "handle_error", _handle_error)
 
 
+@ensure_integration_enabled(SqlalchemyIntegration)
 def _before_cursor_execute(
     conn, cursor, statement, parameters, context, executemany, *args
 ):
     # type: (Any, Any, Any, Any, Any, bool, *Any) -> None
-    hub = Hub.current
-    if hub.get_integration(SqlalchemyIntegration) is None:
-        return
-
     ctx_mgr = record_sql_queries(
-        hub,
         cursor,
         statement,
         parameters,
@@ -69,19 +65,21 @@ def _before_cursor_execute(
 
     if span is not None:
         _set_db_data(span, conn)
-        if hub.client:
-            options = hub.client.options["_experiments"].get("attach_explain_plans")
-            if options is not None:
-                attach_explain_plan_to_span(
-                    span,
-                    conn,
-                    statement,
-                    parameters,
-                    options,
-                )
+        options = (
+            sentry_sdk.get_client().options["_experiments"].get("attach_explain_plans")
+        )
+        if options is not None:
+            attach_explain_plan_to_span(
+                span,
+                conn,
+                statement,
+                parameters,
+                options,
+            )
         context._sentry_sql_span = span
 
 
+@ensure_integration_enabled(SqlalchemyIntegration)
 def _after_cursor_execute(conn, cursor, statement, parameters, context, *args):
     # type: (Any, Any, Any, Any, Any, *Any) -> None
     ctx_mgr = getattr(
@@ -92,6 +90,11 @@ def _after_cursor_execute(conn, cursor, statement, parameters, context, *args):
         context._sentry_sql_span_manager = None
         ctx_mgr.__exit__(None, None, None)
 
+    span = getattr(context, "_sentry_sql_span", None)  # type: Optional[Span]
+    if span is not None:
+        with capture_internal_exceptions():
+            add_query_source(span)
+
 
 def _handle_error(context, *args):
     # type: (Any, *Any) -> None
@@ -119,7 +122,7 @@ def _handle_error(context, *args):
 # See: https://docs.sqlalchemy.org/en/20/dialects/index.html
 def _get_db_system(name):
     # type: (str) -> Optional[str]
-    name = text_type(name)
+    name = str(name)
 
     if "sqlite" in name:
         return "sqlite"
@@ -145,6 +148,9 @@ def _set_db_data(span, conn):
     if db_system is not None:
         span.set_data(SPANDATA.DB_SYSTEM, db_system)
 
+    if conn.engine.url is None:
+        return
+
     db_name = conn.engine.url.database
     if db_name is not None:
         span.set_data(SPANDATA.DB_NAME, db_name)
