@@ -645,6 +645,11 @@ def start_child_span_decorator(func):
             ):
                 return await func(*args, **kwargs)
 
+        try:
+            func_with_tracing.__signature__ = inspect.signature(func)  # type: ignore[attr-defined]
+        except Exception:
+            pass
+
     # Synchronous case
     else:
 
@@ -668,6 +673,11 @@ def start_child_span_decorator(func):
             ):
                 return func(*args, **kwargs)
 
+        try:
+            func_with_tracing.__signature__ = inspect.signature(func)  # type: ignore[attr-defined]
+        except Exception:
+            pass
+
     return func_with_tracing
 
 
